/*
 * Copyright 2016-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.user.roles;

import org.onosproject.nemo.model.common.UserRoleName;

import static com.google.common.base.MoreObjects.toStringHelper;

import java.util.Objects;

/**
 * The key to differentiate user roles.
 */
public class UserRoleKey {
    private final UserRoleName roleName;

    /**
     * Creates a user role key from a given role name.
     *
     * @param roleName the role name
     */
    public UserRoleKey(UserRoleName roleName) {
        this.roleName = roleName;
    }

    /**
     * Creates a copy from a given user role key instance.
     *
     * @param source the user role key
     */
    public UserRoleKey(UserRoleKey source) {
        this.roleName = source.roleName;
    }

    /**
     * Returns the user role name of this instance.
     *
     * @return role name
     */
    public UserRoleName getRoleName() {
        return roleName;
    }

    @Override
    public int hashCode() {
        return roleName.hashCode();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        UserRoleKey other = (UserRoleKey) obj;
        return Objects.equals(roleName, other.roleName);
    }

    @Override
    public String toString() {
        return toStringHelper(this).add("rolename", roleName).toString();
    }
}