/*
 * Copyright 2016-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.intent.structure.style.nemo.delete.input;

import static org.junit.Assert.assertEquals;

import java.util.ArrayList;
import java.util.List;

import org.junit.Test;
import org.onosproject.nemo.model.common.OperationId;
import com.google.common.testing.EqualsTester;

/**
 * Unit tests for {@link OperationsBuilder}.
 */
public class OperationsBuilderTest {

    private static final String OPERATIONS_ERROR_MSG =
            "operations not set";
    private static final String ID = "00000000-0000-0000-0000-000000000000";
    private static final String OTHER_ID = "00000000-0000-0000-0000-000000000001";

    private List<OperationId> operationIdList;
    private List<OperationId> otherList;
    private Operations operations;
    private Operations copy;
    private Operations diff;
    private OperationId operationID;
    private OperationId otheroperationID;

    @Test
    public void buildOperationsWithOperationIDlist() {
        operationIdList = new ArrayList<>();
        operations = new OperationsBuilder()
                .operationIds(operationIdList)
                .build();
        assertEquals(OPERATIONS_ERROR_MSG, operationIdList,
                operations.getOperationIds());
    }

    @Test
    public void fromOperations() {
        operationIdList = new ArrayList<>();
        operations = new OperationsBuilder()
                .operationIds(operationIdList)
                .build();
        copy = new OperationsBuilder(operations).build();
        assertEquals(OPERATIONS_ERROR_MSG, operationIdList,
                copy.getOperationIds());
    }

    @Test
    public void equality() {
        operationIdList = new ArrayList<>();
        operations = new OperationsBuilder().operationIds(operationIdList).build();
        otherList = new ArrayList<>();
        otherList.add(null);
        copy = new OperationsBuilder().operationIds(operationIdList).build();
        diff = new OperationsBuilder().operationIds(otherList).build();
        new EqualsTester()
                .addEqualityGroup(operations, copy)
                .addEqualityGroup(diff)
                .testEquals();
    }

    @Test
    public void equalityTwo() {
        operationID = new OperationId(ID);
        otheroperationID = new OperationId(OTHER_ID);
        operationIdList = new ArrayList<>();
        operationIdList.add(operationID);
        operations = new OperationsBuilder().operationIds(operationIdList).build();
        otherList = new ArrayList<>();
        otherList.add(otheroperationID);
        copy = new OperationsBuilder().operationIds(operationIdList).build();
        diff = new OperationsBuilder().operationIds(otherList).build();
        new EqualsTester()
                .addEqualityGroup(operations, copy)
                .addEqualityGroup(diff)
                .testEquals();
    }
}